@@ -51,6 +51,10 @@ def coerce_if_known_type(value: Any) -> Any:
         if isinstance(value, _types):
             return func(value)
 
+    # Handle generic classes not recognized by inspect.isclass()
+    if str(value).startswith('<class'):
+        return str(value)
+
     return value
 
 
